.. _user:

################
NumPy user guide
################

This guide is an overview and explains the important features;
details are found in :ref:`reference`.

.. toctree::
   :caption: Getting started
   :maxdepth: 1

   whatisnumpy
   Installation <https://numpy.org/install/>
   quickstart
   absolute_beginners

.. toctree::
   :caption: Fundamentals and usage
   :maxdepth: 2

   basics

.. toctree::
   :maxdepth: 1

   numpy-for-matlab-users
   NumPy tutorials <https://numpy.org/numpy-tutorials/>
   howtos_index

.. toctree::
   :caption: Advanced usage and interoperability
   :maxdepth: 1

   c-info
   ../f2py/index
   ../dev/underthehood
   basics.interoperability

.. Links to these files are placed directly in the top-level html
   (doc/source/_templates/indexcontent.html, which appears for the URLs
   numpy.org/devdocs and numpy.org/doc/XX) and are not in any toctree, so
   we include them here to avoid a "WARNING: document isn't included in any
   toctree" message

.. toctree::
   :hidden:
   :caption: Extras

   ../glossary
   ../release
   ../numpy_2_0_migration_guide
   ../license
